@@ -22,6 +22,7 @@ import bz2
 from collections import defaultdict
 import contextlib
 from copy import deepcopy
+from datetime import timedelta
 import glob
 import gzip
 import hashlib
@@ -34,12 +35,16 @@ import tarfile
 import zipfile
 
 
+class NullHandler(logging.Handler):
+    def emit(self, record):
+        pass
+
+
 def buffer_iterator_to_line_iterator(iterator):
     """boto's file iterator splits by buffer size instead of by newline. This
     wrapper puts them back into lines.
     """
-    prepend = ""
-    buf = iterator.next()
+    buf = iterator.next()  # might raise StopIteration, but that's okay
     while True:
         if '\n' in buf:
             (line, buf) = buf.split('\n', 1)
@@ -110,6 +115,13 @@ def hash_object(obj):
     return m.hexdigest()
 
 
+def log_to_null(name=None):
+    """Set up a null handler for the given stream, to suppress
+    "no handlers could be found" warnings."""
+    logger = logging.getLogger(name)
+    logger.addHandler(NullHandler())
+
+
 def log_to_stream(name=None, stream=None, format=None, level=None,
                   debug=False):
     """Set up logging.
@@ -441,6 +453,14 @@ def safeeval(expr, globals=None, locals=None):
     return eval(expr, safe_globals, locals)
 
 
+def strip_microseconds(delta):
+    """Return the given :py:class:`datetime.timedelta`, without microseconds.
+
+    Useful for printing :py:class:`datetime.timedelta` objects.
+    """
+    return timedelta(delta.days, delta.seconds)
+
+
 def tar_and_gzip(dir, out_path, filter=None, prefix=''):
     """Tar and gzip the given *dir* to a tarball at *out_path*.
 
